#=======================================================================
#	$Id: MySQL.pm,v 1.1 2005/11/26 19:57:39 pythontech Exp $
#	Redland MySQL model
#	Copyright (C) 2005  Python Technology Limited
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
#	02111-1307, USA.
#=======================================================================
package PythonTech::Triples::Redland::MySQL;
use strict;
use PythonTech::Triples::Redland;

our @ISA = qw(PythonTech::Triples::Redland);

#-----------------------------------------------------------------------
#	Create a new triplestore in MySQL database using Redland
#	  host		Database hostname (default: 'localhost')
#	  database	MySQL database name
#	  user		User name
#	  password	By which user identified to mysql
#	  name		Model name within Redland MySQL database
#	  new		If true, will clear and create model as new
#-----------------------------------------------------------------------
sub new {
    my $class = shift;
    my $props = {@_};
    foreach my $p (qw(name database user password)) {
	die "$class: no '$p' defined" unless defined $props->{$p};
    }
    $props->{'host'} ||= 'localhost';
    my $options = join(',',
		       map {"$_='$props->{$_}'"} 
		       qw(host database user password));
    $options .= ",new='yes'" if $props->{'new'};

    my $storage = new RDF::Redland::Storage("mysql", $props->{'name'},
					    $options)
	or die "Cannot create Redland mysql storage\n";
    my $model = new RDF::Redland::Model($storage, "")
	or die "Cannot create Redland model\n";
    my $self = {
	storage => $storage,
	model => $model,
    };
    bless $self, $class;
    return $self;
}

1;
